==> picomc-0.3.6.tar.gz: picomc-0.3.6/picomc/cli/account.py <==
import click

from picomc.account import AccountError, OfflineAccount, OnlineAccount, RefreshError
from picomc.env import Env
from picomc.yggdrasil import AuthenticationError


def account_cmd(fn):
    return click.argument("account")(fn)


@click.group()
def account_cli():
    """Manage your accounts."""
    pass


@account_cli.command("list")
def _list():
    """List avaiable accounts."""
    alist = Env.am.list()
    if alist:
        print(
            "\n".join(
                "{}{}".format("* " if Env.am.is_default(u) else "  ", u) for u in alist
            )
        )
    else:
        print("No accounts.")


@account_cli.command()
@account_cmd
@click.argument("mojang_username", default="")
def create(account, mojang_username):
    """Create an account."""
    try:
        if mojang_username:
            acc = OnlineAccount.new(account, mojang_username)
        else:
            acc = OfflineAccount.new(account)
        Env.am.add(acc)
    except AccountError as e:
        print(e)


@account_cli.command()
@account_cmd
def authenticate(account):
    """Retrieve access token from Mojang servers using password."""
    import getpass

    try:
        a = Env.am.get(account)
        # add some output here
        p = getpass.getpass("Password: ")
        a.authenticate(p)
        Env.am.save(a)
    except AuthenticationError as e:
        print(e)


@account_cli.command()
@account_cmd
def refresh(account):
    """Refresh access token with Mojang servers."""
    try:
        a = Env.am.get(account)
        a.refresh()
    except (AccountError, RefreshError) as e:
        print(e)


@account_cli.command()
@account_cmd
def remove(account):
    """Remove the account."""
    try:
        Env.am.remove(account)
    except AccountError as e:
        print(e)


@account_cli.command()
@account_cmd
def setdefault(account):
    """Set the account as default."""
    try:
        default = Env.am.get(account)
        Env.am.set_default(default)
    except AccountError as e:
        print(e)


def register_account_cli(picomc_cli):
    picomc_cli.add_command(account_cli, name="account")

==> picomc-0.4.4.tar.gz: picomc-0.4.4/picomc/cli/account.py <==
import click

from picomc.account import AccountError, OfflineAccount, OnlineAccount, RefreshError
from picomc.cli.utils import pass_account_manager
from picomc.yggdrasil import AuthenticationError


def account_cmd(fn):
    return click.argument("account")(fn)


@click.group()
def account_cli():
    """Manage your accounts."""
    pass


@account_cli.command("list")
@pass_account_manager
def _list(am):
    """List avaiable accounts."""
    alist = am.list()
    if alist:
        lines = ("{}{}".format("* " if am.is_default(u) else "  ", u) for u in alist)
        print("\n".join(lines))
    else:
        print("No accounts.")


@account_cli.command()
@account_cmd
@click.argument("mojang_username", required=False)
@pass_account_manager
def create(am, account, mojang_username):
    """Create an account."""
    try:
        if mojang_username:
            acc = OnlineAccount.new(am, account, mojang_username)
        else:
            acc = OfflineAccount.new(am, account)
        am.add(acc)
    except AccountError as e:
        print(e)


@account_cli.command()
@account_cmd
@pass_account_manager
def authenticate(am, account):
    """Retrieve access token from Mojang servers using password."""
    import getpass

    try:
        a = am.get(account)
        p = getpass.getpass("Password: ")
        a.authenticate(p)
    except AuthenticationError as e:
        print(e)


@account_cli.command()
@account_cmd
@pass_account_manager
def refresh(am, account):
    """Refresh access token with Mojang servers."""
    try:
        a = am.get(account)
        a.refresh()
    except (AccountError, RefreshError) as e:
        print(e)


@account_cli.command()
@account_cmd
@pass_account_manager
def remove(am, account):
    """Remove the account."""
    try:
        am.remove(account)
    except AccountError as e:
        print(e)


@account_cli.command()
@account_cmd
@pass_account_manager
def setdefault(am, account):
    """Set the account as default."""
    try:
        default = am.get(account)
        am.set_default(default)
    except AccountError as e:
        print(e)


def register_account_cli(picomc_cli):
    picomc_cli.add_command(account_cli, name="account")
